.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment:

=======================
 Semantic Segmentation
=======================

.. toctree::
   :maxdepth: 1

   avdrive
   chasedb1
   cxr8
   drhagis
   drionsdb
   drishtigs1
   drive
   hrf
   iostar
   jsrt
   montgomery
   refuge
   rimoner3
   shenzhen
   stare
